---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'type: bug'

---

#### Describe the bug
A clear and concise description of what the bug is.

#### To Reproduce
Steps to reproduce the behavior:
```
Minimum working example of code
```

#### Expected behavior
A clear and concise description of what you expected to happen.

#### Python environement:
 - exSpy version: 0.x.x
 - HyperSpy version: 1.x.x
 - Python version: 3.x

#### Additional context
Add any other context about the problem here. If necessary, add screenshots to help explain your problem.
